# gpt2Api-Client

Under construction!

Developed by Anirudh from TechWithAnirudh (c) 2021

## Examples of How To Use (Alpha Version)

Creating A Request
```python
start_paragraph = "Today was a fine day. I woke up and brushed my teeth. And Ate Breakfast. I was going to work When"
api = Api()
api.setApiUrl(input('Enter The Api URL: '))
print(api.ConditionalSamples(start_paragraph))
```

```python
start_paragraph = "Today was a fine day. I woke up saw some news that the coding event is starting today. I love coding so I prepared. After I prepared"
api = Api()
api.setApiUrl(input('Enter The Api URL: '))
print(api.ConditionalSamples(start_paragraph))
```

Go to this url: https://github.com/techwithanirudh/Shared/blob/master/GPT2Api.ipynb
And run the code
copy the url called GPT2ApiURL=...
and paste it here.
This will give the json response

Very Easy To To Use GPT2 Wrapper

## Info

See The Docs On How To Use This: https://techwithanirudh.blogspot.com/2021/03/docs-for-gpt2api-client-module.html

Check out: https://www.youtube.com/channel/UCmse86kaxJ3n1dDT_bXDukg